package com.info666.infraredRemote.controller;

import com.alibaba.fastjson2.JSON;
import com.alibaba.fastjson2.JSONObject;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.ruoyi.common.core.baiduMap.SearchHttpAK;
import com.ruoyi.common.core.domain.R;
import com.ruoyi.common.core.redis.RedisCache;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.system.domain.UserAddress;
import com.ruoyi.system.domain.UserInfo;
import com.ruoyi.system.domain.vo.SmsResponseVo;
import com.ruoyi.system.domain.vo.baiduMap.Result;
import com.ruoyi.system.service.UserAddressService;
import com.ruoyi.system.service.UserInfoService;
import org.apache.poi.ss.formula.functions.T;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.regex.Pattern;

/**
 * @Author: LiMingMing
 * @Date: 2023/8/1 16:09
 * @Description: TODO
 **/
@RestController
@RequestMapping("/api/v1/user")
public class UserLoginController {

    @Autowired
    private UserInfoService userInfoService;

    @Autowired
    private UserAddressService userAddressService;

    @Autowired
    private RedisCache redisCache;

    @Autowired
    private SearchHttpAK searchHttpAK;

    /**
     * 登录接口
     */
    @PostMapping("/login")
    public R<SmsResponseVo> sendSms(@RequestBody UserInfo param) {
        if (StringUtils.isEmpty(param.getUserPhone()) || Pattern.matches("^1[3-9]\\d{9}$\n",param.getUserPhone())){
            return R.fail("手机号格式不正确");
        }
        if (StringUtils.isEmpty(param.getCode())){
            return R.fail("验证不能为空");
        }
        UserInfo userInfo = userInfoService.getOne(new LambdaQueryWrapper<UserInfo>().eq(UserInfo::getUserPhone,param.getUserPhone()),false);
        if (userInfo == null){
            param.setCreateTime(DateUtils.getNowDate());
            userInfoService.save(param);
        }
        if (!redisCache.getCacheObject(param.getKeyCode()).equals(param.getCode())){
            return R.fail("验证码错误");
        }
        return R.ok();
    }

    /**
     * 上传用户地址
     */
    @PostMapping("/uploadAddress")
    public R<T> uploadAddress(@RequestBody UserAddress param) throws Exception {
        UserInfo one = userInfoService.getOne(new LambdaQueryWrapper<UserInfo>().eq(UserInfo::getUserPhone, param.getUserPhone()),false);
        if ( StringUtils.isEmpty(param.getLongitude()) || StringUtils.isEmpty(param.getLatitude())){
            return R.fail("经纬度信息不能为空");
        }
        String data = searchHttpAK.convertIp(param.getLatitude()+","+param.getLongitude());
        JSONObject json = JSON.parseObject(data);
            Integer status = json.getInteger("status");
        if (status != 0){
            return R.fail("经纬度转换失败 状态码:{}"+status);
        }
        String result = json.getString("result");
        Result detail = JSONObject.parseObject(result, Result.class);
        param.setFormattedAddress(detail.getFormatted_address());
        param.setProvince(detail.getAddressComponent().getProvince());
        param.setCity(detail.getAddressComponent().getCity());
        param.setDistrict(detail.getAddressComponent().getDistrict());
        param.setTown(detail.getAddressComponent().getTown());
        param.setStreet(detail.getAddressComponent().getStreet());
        param.setUserId(one.getId());
        param.setCreateTime(DateUtils.getNowDate());
        userAddressService.save(param);
        return R.ok();
    }




}
